@@ -1,11 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2002,2003 Free Software Foundation, Inc.
+   Copyright (C) 2002,2003,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -24,29 +24,31 @@
 #define CS_BLOCK 1
 
 typedef struct {
-	UINT4 ipaddr;
-	UINT4 netmask;
+	grad_uint32_t ipaddr;
+	grad_uint32_t netmask;
 } cfg_network_t;
 
 typedef struct {
-	UINT4 ipaddr;
+	grad_uint32_t ipaddr;
 	int port;
 } cfg_host_t;
 
-#define CFG_INTEGER 0
-#define CFG_BOOLEAN 1
-#define CFG_STRING  2
-#define CFG_NETWORK 3
-#define CFG_IPADDR  4
-#define CFG_PORT    5
-#define CFG_CHAR    6
-#define CFG_HOST    7
+#define CFG_INTEGER  0
+#define CFG_BOOLEAN  1
+#define CFG_STRING   2
+#define CFG_NETWORK  3
+#define CFG_IPADDR   4
+#define CFG_PORT     5
+#define CFG_CHAR     6
+#define CFG_HOST     7
+#define CFG_UNSIGNED 8
+#define CFG_SIZE_T   9
 
 typedef struct {
         int type;
         union {
 		char *string;
-                UINT4 ipaddr;
+                grad_uint32_t ipaddr;
                 size_t number;
                 int bool;
 		cfg_network_t network;
@@ -85,6 +87,12 @@ int cfg_get_ipaddr(int argc, cfg_value_t *argv,
 		   void *block_data, void *handler_data);
 int cfg_get_integer(int argc, cfg_value_t *argv,
 		    void *block_data, void *handler_data);
+int cfg_get_unsigned(int argc, cfg_value_t *argv,
+		     void *block_data, void *handler_data);
+int cfg_get_size_t(int argc, cfg_value_t *argv,
+		   void *block_data, void *handler_data);
+int cfg_get_uint32_t(int argc, cfg_value_t *argv,
+		     void *block_data, void *handler_data);
 int cfg_get_number(int argc, cfg_value_t *argv,
 		   void *block_data, void *handler_data);
 int cfg_get_string(int argc, cfg_value_t *argv,
