@@ -1,11 +1,12 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2007,
+   2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -21,7 +22,7 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-#include <common.h>
+#include <radlib.h>
 
 static grad_list_t /* of grad_nas_t */ *naslist;      /* raddb/naslist */
 
@@ -51,7 +52,7 @@ read_naslist_entry(void *unused ARG_UNUSED, int fc, char **fv, grad_locus_t *loc
         grad_nas_t nas, *nasp;
 
         if (fc < 2) {
-                grad_log_loc(L_ERR, loc, "%s", _("too few fields"));
+                grad_log_loc(GRAD_LOG_ERR, loc, "%s", _("too few fields"));
                 return -1;
         }
 
