@@ -1,11 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2002,2003,2004,2006,2007 Free Software Foundation, Inc.
+   Copyright (C) 2002,2003,2004,2006,2007,2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -63,14 +63,14 @@ grad_server_send_reply(int fd, grad_request_t *radreq,
                 sin->sin_addr.s_addr = htonl(radreq->ipaddr);
                 sin->sin_port = htons(radreq->udp_port);
 #ifdef DEBUG_ONLY
-		grad_log(L_DEBUG,
+		grad_log(GRAD_LOG_DEBUG,
 			 "DEBUG_ONLY version: not sending %s of id %d to %s (nas %s)",
 			 grad_request_code_to_name(reply_code), 
 			 radreq->id,
 			 grad_ip_iptostr(radreq->ipaddr, NULL),
 			 grad_nas_request_to_name(radreq, buf, sizeof buf));
 #else		
-                GRAD_DEBUG4(1, "Sending %s of id %d to %s (nas %s",
+                GRAD_DEBUG4(1, "Sending %s of id %d to %s (nas %s)",
                           grad_request_code_to_name(reply_code), 
                           radreq->id,
 			  grad_ip_iptostr(radreq->ipaddr, NULL),
@@ -120,7 +120,7 @@ grad_server_send_challenge(int fd, grad_request_t *radreq,
                 sin->sin_port = htons(radreq->udp_port);
 
 #ifdef DEBUG_ONLY
-		grad_log(L_DEBUG,
+		grad_log(GRAD_LOG_DEBUG,
 			 "DEBUG_ONLY version: not sending challenge of id %d to %s (nas %s)",
 			 radreq->id, grad_ip_iptostr(radreq->ipaddr, NULL),
 			 grad_nas_request_to_name(radreq, buf, sizeof buf)));
