@@ -1,11 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2001,2003,2004,2006,2007 Free Software Foundation, Inc.
+   Copyright (C) 2001,2003,2004,2006,2007,2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -59,7 +59,7 @@ rad_pam_conv(int num_msg, const struct pam_message **msg,
         int rc;
 
         if (!data) {
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
                          _("rad_pam_conv(): no application-specific data passed"));
                 return PAM_CONV_ERR;
         }
