@@ -1,12 +1,12 @@
 /*
    This file is part of GNU Radius SNMP Library.
-   Copyright (C) 2001,2003 Free Software Foundation, Inc.
+   Copyright (C) 2001,2003,2004,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License as
-   published by the Free Software Foundation; either version 2.1 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
@@ -25,8 +25,8 @@
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <asn1.h>
-#include <snmp.h>
+#include <snmp/asn1.h>
+#include <snmp/snmp.h>
 
 oid_t
 oid_dup(oid_t oid)
